@@ -17,8 +17,8 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 import copy
 import re
 
-import externalPlots as externalPlots
-from pos_neg_evolution_init import posNegEvolutionMainLoop as pnEML 
+import posNegEvolution.externalPlots as externalPlots
+from posNegEvolution.pos_neg_evolution_init import posNegEvolutionMainLoop as pnEML 
 
 disclaimer = '''Cellular/Microbial Positive and Negative Mutation Effect Evolution simulations basing on Gillespie algorithm. Copyright (C) 2022 by Jarosław Gil. 
     This program comes with ABSOLUTELY NO WARRANTY.
